@@ -102,14 +102,6 @@ class AdjustedZopeCmd(zopectl.ZopeCmd):
         # We overwrite the test command to populate the search path
         # automatically with all configured products and eggs.
         args = filter(None, arg.split(' '))
-
-        # Disable deprecation warnings if desired
-        for nowarn in '--nowarn', '--nowarning':
-            if nowarn in args:
-                args.remove(nowarn)
-                from warnings import filterwarnings
-                filterwarnings("ignore", ".*", DeprecationWarning)
-
         defaults = []
         softwarehome = self.options.configroot.softwarehome
 
@@ -148,21 +140,10 @@ class AdjustedZopeCmd(zopectl.ZopeCmd):
         # are found by the testrunner
         paths = sys.path
         progname = self.options.progname
-        buildout_root =  os.path.split(os.path.dirname(progname))[0]
-        paths = [p for p in paths if p != buildout_root]
+        buildout_root = os.path.dirname(os.path.dirname(progname))
 
-        # If we have a package filter, we don't put any packages on the test
-        # path that do not match the package filter
-        package = None
-        if '-s' in args:
-            index = args.index('-s')
-            if len(args) > index:
-                package = args[index + 1]
         for path in paths:
-            if package is not None:
-                if package in path:
-                    defaults += ['--test-path', path]
-            else:
+            if path != buildout_root:
                 defaults += ['--test-path', path]
 
         # Default to dots, if not explicitly set to quiet. Don't duplicate
@@ -170,9 +151,19 @@ class AdjustedZopeCmd(zopectl.ZopeCmd):
         if '-v' not in args and '-q' not in args:
             defaults.append('-v')
 
+        # Add the --nowarnings option.
+        import zope.testing.testrunner
+
+        def filter_warnings(option, opt, *ignored):
+            import warnings
+            warnings.simplefilter('ignore', Warning, append=True)
+
+        zope.testing.testrunner.other.add_option(
+            '--nowarnings', action='callback', callback=filter_warnings,
+            help="Install a filter to suppress warnings emitted by code.\n")
+
         # Run the testrunner. Calling it directly ensures that it is executed
         # in the same environment that we just carefully configured.
-        import zope.testing.testrunner
         args.insert(0, zope.testing.testrunner.__file__)
         zope.testing.testrunner.run(defaults, args)
 
